@@ -2,6 +2,7 @@ import PyQt5.QtWidgets as qtWidget
 import PyQt5.QtGui as qtGui
 from PyQt5.QtCore import Qt
 import sys
+import os
 import numpy as np
 import scipy as sc
 import pandas as pd
@@ -12,10 +13,10 @@ import re
 from threading import Thread
 from multiprocessing import Process, Queue
 
-from seEvo_evolution_init import seEvoInit
-import externalPlots as externalPlots
-# from seEvo1D.seEvo_evolution_init import seEvoInit
-# import seEvo1D.externalPlots as externalPlots
+# from seEvo_evolution_init import seEvoInit
+# import externalPlots as externalPlots
+from seEvo1D.seEvo_evolution_init import seEvoInit
+import seEvo1D.externalPlots as externalPlots
 
 disclaimer = '''
     seEvo - slightly effect evolution simulator basing on Gillespie algorithm.
@@ -197,18 +198,26 @@ class mainFormat(qtWidget.QWidget):
         if self._th_ed.is_alive():
             self.showDialog("plottin already running", 'Info')
             return
-        self.showDialog("First select ANALYTICAL .npz files (whole population)\n Second select NORMAL .npz files (whole population)", "INFO")
-        fname_an = qtWidget.QFileDialog.getOpenFileNames(None, 'Select Analytical Files', "Z://","Data File (*.npz)")[0] 
-        if len(fname_an) == 0:
-            self.showDialog("No analytical file selected", "Alert")
+        # self.showDialog("First select ANALYTICAL .npz folder (whole population)\n Second select NORMAL .npz folder (whole population)", "INFO")
+        # fname_an = qtWidget.QFileDialog.getOpenFileName(None, 'Select Analytical Files', "Z://","Data File (*.npz)")[0] 
+        fname = qtWidget.QFileDialog.getExistingDirectory(self,"Choose Directory","Z:/")
+        if fname == '':
+            self.showDialog("No analytical folder selected", "Alert")
             return
+        fname_an = np.array(os.listdir(fname))
+        fname_an = np.array(list(map(lambda x,y: (y + '/' + x)*x.endswith('.npz'), fname_an, np.repeat(fname, len(fname_an)))))
+        fname_an = fname_an[fname_an != '']
         if not all(map(lambda x: 'analytical' in x, fname_an)):
             self.showDialog("Select only analytical files", "Alert")
             return
-        fname_norm = qtWidget.QFileDialog.getOpenFileNames(None, 'Select Normal Files', "Z://","Data File (*.npz)")[0] 
-        if len(fname_norm) == 0:
-            self.showDialog("No normal file selected", "Alert")
+        # fname_norm = qtWidget.QFileDialog.getOpenFileNames(None, 'Select Normal Files', "Z://","Data File (*.npz)")[0] 
+        fname = qtWidget.QFileDialog.getExistingDirectory(self,"Choose Directory","Z:/")
+        if fname == '':
+            self.showDialog("No normal folder selected", "Alert")
             return
+        fname_norm = np.array(os.listdir(fname))
+        fname_norm = np.array(list(map(lambda x,y: (y + '/' + x)*x.endswith('.npz'), fname_norm, np.repeat(fname, len(fname_norm)))))
+        fname_norm = fname_norm[fname_norm != '']
         if not all(map(lambda x: 'normal' in x, fname_norm)):
             self.showDialog("Select only normal files", "Alert")
             return
